declare class BaseError extends Error {
    cause: any | undefined;
    constructor(message: string, cause?: any);
}
export declare class VerificationError extends BaseError {
}
export declare class ValidationError extends BaseError {
}
export declare class PolicyError extends BaseError {
}
type InternalErrorCode = 'TLOG_FETCH_ENTRY_ERROR' | 'TLOG_CREATE_ENTRY_ERROR' | 'CA_CREATE_SIGNING_CERTIFICATE_ERROR' | 'TSA_CREATE_TIMESTAMP_ERROR' | 'TUF_FIND_TARGET_ERROR' | 'TUF_REFRESH_METADATA_ERROR' | 'TUF_DOWNLOAD_TARGET_ERROR' | 'TUF_READ_TARGET_ERROR';
export declare class InternalError extends BaseError {
    code: InternalErrorCode;
    constructor({ code, message, cause, }: {
        code: InternalErrorCode;
        message: string;
        cause?: any;
    });
}
export {};
